==> haskell-chell-0.5.0.2-94.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell
version:              0.5.0.2
visibility:           public
id:                   chell-0.5.0.2-J2NnLqxWjfY68DlKOAlo1D
key:                  chell-0.5.0.2-J2NnLqxWjfY68DlKOAlo1D
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing.
    It natively supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

category:             Testing
abi:                  d66abff6be5763ee7bea56c7b697d763
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell
hs-libraries:         HSchell-0.5.0.2-J2NnLqxWjfY68DlKOAlo1D
depends:
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt base-4.18.2.1
    bytestring-0.11.5.3 options-1.2.1.2-J3to70TLD2KHxKq1xPVSdI
    patience-0.3-FGve9R2EZzO566jluhwsHH
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-0.5.0.2-95-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell
version:              0.5.0.2
visibility:           public
id:                   chell-0.5.0.2-7mRYbmmQgnJ3glUfHFLIH2
key:                  chell-0.5.0.2-7mRYbmmQgnJ3glUfHFLIH2
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing.
    It natively supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

category:             Testing
abi:                  b265e5ab04e705bb5436fc9d4218f4d7
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell
hs-libraries:         HSchell-0.5.0.2-7mRYbmmQgnJ3glUfHFLIH2
depends:
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh base-4.18.2.1
    bytestring-0.11.5.3 options-1.2.1.2-Ll8emrwh5ZZ69kZWAqaJpB
    patience-0.3-FGve9R2EZzO566jluhwsHH
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
